@@ -1,6 +1,6 @@
 package Text::RecordParser;
 
-# $Id: RecordParser.pm,v 1.2 2006/02/08 15:05:11 kclark Exp $
+# $Id: RecordParser.pm,v 1.7 2006/02/17 16:49:41 kclark Exp $
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Text::RecordParser - read record-oriented files
 
 =head1 VERSION
 
-This documentation refers to version 1.0.0.
+This documentation refers to version 1.1.0.
 
 =head1 SYNOPSIS
 
@@ -87,7 +87,7 @@ use IO::Scalar;
 use Readonly;
 use Text::ParseWords qw( parse_line );
 
-use version; our $VERSION = qv('1.0.1');
+use version; our $VERSION = qv('1.1.0');
 
 Readonly my $COMMA     => ',';
 Readonly my $EMPTY_STR => q{};
@@ -441,10 +441,11 @@ of the fields.
 
     my $separator = $self->field_separator;
     $separator eq $PIPE and $separator = '\|';
-    my @fields    = ref $separator eq 'Regexp'
+    my @fields    = map { $_ =~ s/\\'/'/g; $_ } (
+        ( ref $separator eq 'Regexp' )
         ? parse_line( $separator, 0, $line )
         : parse_line( $separator, 1, $line )
-    ;
+    );
 
     if ( !@fields ) {
         croak "Error reading line number $line_no:\n$line";
@@ -1019,7 +1020,7 @@ None known.  Please use http://rt.cpan.org/ for reporting bugs.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2005 Ken Youens-Clark.  All rights reserved.
+Copyright (C) 2006 Ken Youens-Clark.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
